==> haskell-http-conduit-2.1.8-22-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.1.8
id: http-conduit-2.1.8-e4b3137b3a617f6e2e89e01e265fce1e
key: httpc_GruWuAgBf5y0nptB9MIKMf
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    This package uses conduit for parsing the actual contents of the HTTP connection. It also provides higher-level functions which allow you to avoid directly dealing with streaming data. See <http://www.yesodweb.com/book/http-conduit> for more information.
    .
    The @Network.HTTP.Conduit.Browser@ module has been moved to <http://hackage.haskell.org/package/http-conduit-browser/>
category: Web, Conduit
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.HTTP.Conduit Network.HTTP.Client.Conduit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http-conduit-2.1.8
library-dirs: /usr/lib/ghc-7.10.3/site-local/http-conduit-2.1.8
data-dir: /usr/share/arm-linux-ghc-7.10.3/http-conduit-2.1.8
hs-libraries: HShttp-conduit-2.1.8-GruWuAgBf5y0nptB9MIKMf
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.1-0dc23cc567e1e45fd451d3d7a1cbf2ca
    http-client-0.4.27-cb2c2811d5497a3b5f8310fdf3cadc3f
    http-client-tls-0.2.2-a568dba4ad303022988fc1cb539c259c
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    resourcet-1.1.7.1-53b70bd9a277fdc9d256cfbf9605d278
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.1.8-23-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.1.8
id: http-conduit-2.1.8-e2c4d8f7b8297fdf1ac5b7f32d06d5dd
key: httpc_2yxpgEgcRZwFfLz6pNTsQo
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    This package uses conduit for parsing the actual contents of the HTTP connection. It also provides higher-level functions which allow you to avoid directly dealing with streaming data. See <http://www.yesodweb.com/book/http-conduit> for more information.
    .
    The @Network.HTTP.Conduit.Browser@ module has been moved to <http://hackage.haskell.org/package/http-conduit-browser/>
category: Web, Conduit
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.HTTP.Conduit Network.HTTP.Client.Conduit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http-conduit-2.1.8
library-dirs: /usr/lib/ghc-7.10.3/site-local/http-conduit-2.1.8
data-dir: /usr/share/arm-linux-ghc-7.10.3/http-conduit-2.1.8
hs-libraries: HShttp-conduit-2.1.8-2yxpgEgcRZwFfLz6pNTsQo
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.1-20c379c1e33e978c5d5c8f5ef78dd0c3
    http-client-0.4.27-cb2c2811d5497a3b5f8310fdf3cadc3f
    http-client-tls-0.2.2-a568dba4ad303022988fc1cb539c259c
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    resourcet-1.1.7.1-34b9e931a3d19e984bea5de562a18bbd
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
